==> okapi-lib-1.41.0-sources.jar: net/sf/okapi/common/resource/CodeComparatorOnData.java <==
/*===========================================================================
  Copyright (C) 2016-2017 by the Okapi Framework contributors
-----------------------------------------------------------------------------
  Licensed under the Apache License, Version 2.0 (the "License");
  you may not use this file except in compliance with the License.
  You may obtain a copy of the License at

  http://www.apache.org/licenses/LICENSE-2.0

  Unless required by applicable law or agreed to in writing, software
  distributed under the License is distributed on an "AS IS" BASIS,
  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
  See the License for the specific language governing permissions and
  limitations under the License.
===========================================================================*/

package net.sf.okapi.common.resource;

import java.util.Comparator;

import net.sf.okapi.common.StringUtil;

public class CodeComparatorOnData implements Comparator<Code> {

	@Override
	public int compare(Code c1, Code c2) {	  
		// FIXME: remove whitespace because the XLIFF/TMX etc.. code data may be normalized
		String data1 = StringUtil.removeWhiteSpace(c1.getData());
		String data2 = StringUtil.removeWhiteSpace(c2.getData());
				
		if (data1.equals(data2) && c1.getTagType() == c2.getTagType()) {			
			return 0;
		} else if (data1.equals(data2) && c1.getTagType() != c2.getTagType()) {
			return c1.getTagType().compareTo(c2.tagType); 
		} else {
			return data1.compareTo(data2);
		}
	}
}

==> okapi-lib-1.42.0-sources.jar: net/sf/okapi/common/resource/CodeComparatorOnData.java <==
/*===========================================================================
  Copyright (C) 2016-2017 by the Okapi Framework contributors
-----------------------------------------------------------------------------
  Licensed under the Apache License, Version 2.0 (the "License");
  you may not use this file except in compliance with the License.
  You may obtain a copy of the License at

  http://www.apache.org/licenses/LICENSE-2.0

  Unless required by applicable law or agreed to in writing, software
  distributed under the License is distributed on an "AS IS" BASIS,
  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
  See the License for the specific language governing permissions and
  limitations under the License.
===========================================================================*/

package net.sf.okapi.common.resource;

import net.sf.okapi.common.StringUtil;
import net.sf.okapi.common.Util;

import java.util.Comparator;

public class CodeComparatorOnData implements Comparator<Code> {

	@Override
	public int compare(Code c1, Code c2) {
		if (c1 == c2) {
			return 0;
		}

		if (c1 == null || c2 == null) {
			return -1;
		}

		if (Util.isEmpty(c1.getData()) && Util.isEmpty(c2.getData())) {
			return 0;
		}

		if (Util.isEmpty(c1.getData()) || Util.isEmpty(c2.getData())) {
			return -1;
		}

		// FIXME: remove whitespace because the XLIFF/TMX etc.. code data may be normalized
		String data1 = StringUtil.removeWhiteSpace(c1.getData());
		String data2 = StringUtil.removeWhiteSpace(c2.getData());
		return data2.compareTo(data1);
	}
}
